@@ -1,21 +1,24 @@
 from office365.actions.download_content_query import DownloadContentQuery
 from office365.actions.search_query import SearchQuery
 from office365.actions.upload_content_query import UploadContentQuery
+from office365.directory.applicationCollection import ApplicationCollection
 from office365.directory.directory import Directory
 from office365.directory.directoryObjectCollection import DirectoryObjectCollection
 from office365.directory.group_collection import GroupCollection
 from office365.directory.groupSettingTemplateCollection import GroupSettingTemplateCollection
+from office365.directory.identityProviderCollection import IdentityProviderCollection
 from office365.directory.user import User
 from office365.directory.userCollection import UserCollection
 from office365.onedrive.driveCollection import DriveCollection
 from office365.onedrive.sharedDriveItemCollection import SharedDriveItemCollection
 from office365.onedrive.siteCollection import SiteCollection
-from office365.outlook.contact_collection import ContactCollection
+from office365.mail.contact_collection import ContactCollection
 from office365.runtime.auth.token_response import TokenResponse
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.odata.odata_request import ODataRequest
+from office365.runtime.odata.odata_v4_batch_request import ODataV4BatchRequest
 from office365.runtime.odata.v4_json_format import V4JsonFormat
 from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.update_entity_query import UpdateEntityQuery
@@ -38,6 +41,11 @@ class GraphClient(ClientRuntimeContext):
         self._authority_host_url = "https://login.microsoftonline.com"
         self._acquire_token_callback = acquire_token_callback
 
+    def execute_batch(self):
+        """Construct and submit a batch request"""
+        batch_request = ODataV4BatchRequest(self)
+        batch_request.execute_query()
+
     def pending_request(self):
         return self._pending_request
 
@@ -135,3 +143,13 @@ class GraphClient(ClientRuntimeContext):
     def directory(self):
         """Represents a deleted item in the directory"""
         return Directory(self, ResourcePath("directory"))
+
+    @property
+    def identityProviders(self):
+        """Represents a deleted item in the directory"""
+        return IdentityProviderCollection(self, ResourcePath("identityProviders"))
+
+    @property
+    def applications(self):
+        """Get the list of applications in this organization."""
+        return ApplicationCollection(self, ResourcePath("applications"))
