@@ -33,8 +33,11 @@ class ClientObject(object):
         self.context.execute_query()
         return self
 
-    def execute_query_retry(self):
-        self.context.execute_query_retry()
+    def execute_query_retry(self, max_retry=5, timeout_secs=5, success_callback=None, failure_callback=None):
+        self.context.execute_query_retry(max_retry=max_retry,
+                                         timeout_secs=timeout_secs,
+                                         success_callback=success_callback,
+                                         failure_callback=failure_callback)
         return self
 
     def build_request(self):
@@ -82,7 +85,7 @@ class ClientObject(object):
         :param str name: property name
         """
         normalized_name = name[0].lower() + name[1:]
-        return getattr(self, normalized_name, self._properties.get(normalized_name, None))
+        return getattr(self, normalized_name, self._properties.get(name, None))
 
     def set_property(self, name, value, persist_changes=True):
         """Sets property value
