@@ -1,5 +1,5 @@
 from office365.runtime.client_object_collection import ClientObjectCollection
-from office365.runtime.client_query import CreateEntityQuery
+from office365.runtime.queries.create_entity_query import CreateEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.principal.user import User
@@ -11,6 +11,12 @@ class UserCollection(ClientObjectCollection):
     def __init__(self, context, resource_path=None):
         super(UserCollection, self).__init__(context, User, resource_path)
 
+    def get(self):
+        """
+        :rtype: UserCollection
+        """
+        return super(UserCollection, self).get()
+
     def add_user(self, login_name):
         """
         Adds a user
