@@ -4,7 +4,7 @@ from office365.runtime.queries.service_operation_query import ServiceOperationQu
 from office365.runtime.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.publishing.portal_health_status import PortalHealthStatus
-from office365.sharepoint.tenant.administration.hubSiteProperties import HubSiteProperties
+from office365.sharepoint.tenant.administration.hubsite_properties import HubSiteProperties
 from office365.sharepoint.tenant.administration.secondary_administrators_fields_data import \
     SecondaryAdministratorsFieldsData
 from office365.sharepoint.tenant.administration.secondary_administrators_info import SecondaryAdministratorsInfo
@@ -20,6 +20,21 @@ class Tenant(BaseEntity):
         super().__init__(context, ResourcePath("Microsoft.Online.SharePoint.TenantAdministration.Tenant"),
                          "Microsoft.Online.SharePoint.TenantAdministration")
 
+    @staticmethod
+    def from_url(admin_site_url):
+        from office365.sharepoint.client_context import ClientContext
+        admin_client = ClientContext(admin_site_url)
+        return Tenant(admin_client)
+
+    def get_lock_state_by_id(self, site_id):
+        return self._sites.get_lock_state_by_id(site_id)
+
+    def hub_sites(self, siteUrl):
+        pass
+
+    def connect_site_to_hub_site_by_id(self, siteUrl, hubSiteId):
+        pass
+
     def check_tenant_licenses(self, licenses):
         """
         Checks whether a tenant has the specified licenses.
