@@ -21,5 +21,5 @@ class WebCollection(ClientObjectCollection):
     def resource_url(self):
         url = super(WebCollection, self).resource_url
         if self._parent_web_url is not None:
-            url = url.replace(self.context.service_root_url, self._parent_web_url + '/_api/')
+            url = url.replace(self.context.service_root_url(), self._parent_web_url + '/_api/')
         return url
